function [iD, iLlr, iBP, iMsqDpl, iTimeStampIndeces, iGraydata, vecD, vecA, vecG, vecResnorm, veloMatrix, alphaMatrix, resnormMatrix, fitMatrix] = MLE_findDiffChangeInterpolated(trackMatrix, trackIndeces, timeStamp, alpha, interpolationDepth, interpolationType, proximityTolerance, grayvalueMatrix)
% interpolationDepth .. interpolated Vector will be iD-times as long as original vector
% interpolationType .. all types interp1.m supports, e.g. 'linear'
% proximityTolerance .. number of time steps difference b/w adjacent bp which will be considered one bp 
% iD..cell array containing D's for subtracks
% iBP .. cell array with breakpoints determining subtracks (in index positions)
% iTimeStampIndeces .. cell array with real time coordinates of subtracks
% vecD .. timesteps x tracks matrix containing plottable D 



stepSize = 1/interpolationDepth;
bpProximityTolerance = interpolationDepth.*proximityTolerance;
deltaT = timeStamp(2);

% Calc displacement
x = displacement(trackMatrix);

% Interpolation
disp('Interpolating...');
iX = INTERP1(1:size(x,1),x,1:stepSize:size(x,1),interpolationType);
iTrackIndeces = INTERP1(1:size(trackIndeces,1),trackIndeces,1:stepSize:size(trackIndeces,1),interpolationType);
disp('done.');

% Split into pieces < 1000 
steps = length(iX);
n = 1000; % CR only defined up to 1000
lengthRatio = floor(steps/n);
for p = 1:lengthRatio
        indeces = (((p-1).*n)+1):(p.*n);
        iiX{p} = iX(indeces,:);
        iiTrackIndeces{p} = iTrackIndeces(indeces, :);
end
% Short tracks
if (lengthRatio == 0)
        iiX{1} = iX;
        iiTrackIndeces{1} = iTrackIndeces(1:size(iiX{1}, 1), :); % this is ultra-dirty!! only to avoid probs in line 51
end;
 % Last piece
if (lengthRatio > 1)
indeces = (lengthRatio.*n+1):(lengthRatio.*n+mod(steps,n));
iiX{lengthRatio+1} = iX(indeces,:);
iiTrackIndeces{lengthRatio+1} = iTrackIndeces(indeces,:);
end;

% Find breakpoints
for j = 1:size(iiX,2) % iterate through pieces
        for i = 1:size(iiX{j},2) % iterate through tracks
                disp(['------------- Processing track #' num2str(i) ' piece #' num2str(j) ' ---------------']);
                k = find(iiTrackIndeces{j}(1:length(iiTrackIndeces{j})-1,i)==1);
                [llr, bp, bp_b] = logLikelihoodRatio(iiX{j}(k,i), 1, 1, alpha);
                iLlr{j}{i} = llr;
                iBP{j}{i} = bp;
                breakpoints_b{j}{i} = bp_b;
        end;
end


disp('Weeding out artefacts...');
% Weeding out boundary effects
iHelp = allocate2DCellArray(iBP);
for j = 1:size(iBP,2) % iterate through pieces
        for i = 1:size(iBP{j}, 2) % iterate through tracks
                tsteps = size(iBP{j}{i}, 1);
                for h = 1:tsteps % iterate through individual BPs
                        if (iBP{j}{i}(h) > bpProximityTolerance) & (iBP{j}{i}(h) < (size(iiX{j},1)-bpProximityTolerance))
                                iHelp{j}{i}(h) = iBP{j}{i}(h); 
                        end;
                end;
                if (tsteps == 0) % in this case the loop was not passed; make sure iHelp has correct dimensions
                        iHelp{j}{i}(h) = 0;
                end;
        end;
end
clear iBP;
iBP = weedOutZeros(iHelp);
clear iHelp;

% Weeding out doubles
iHelp = allocate2DCellArray(iBP);
for j = 1:size(iBP,2) % iterate through pieces
        for i = 1:size(iBP{j}, 2) % iterate through tracks
                iHelp{j}{i} = proximityFilter(iBP{j}{i}, bpProximityTolerance);
        end;
end
clear iBP;
iBP = weedOutZeros(iHelp);
clear iHelp;


% Weeding out BP > steps
iHelp = allocate2DCellArray(iBP);
for j = 1:size(iBP,2) % iterate through pieces
        for i = 1:size(iBP{j}, 2) % iterate through tracks
                maxSteps = size(iiX{j}, 1);
                iHelp{j}{i} = iBP{j}{i}(find(iBP{j}{i} <= maxSteps+1)); 
        end;
end
clear iBP;
iBP = iHelp;
clear iHelp;


% Weeding out BP = 0 introduced by the weeding out procedures before
iBP = weedOutZeros(iBP);
disp ('done weeding out.');


% Assembling pieces into iBP
for d = 1:size(x,2)
        iHelp{d} = [];
end;
%iHelp = cell(size(x,2)); % as many entries as there are tracks
for j = 1:size(iBP,2)-1 % iterate through pieces
        for i = 1:size(iBP{j}, 2) % iterate through tracks
                previous = iHelp{i};
                helpVec = union(iBP{j}{i}+(j-1)*n, iBP{j+1}{i}+(j)*n);
                iHelp{i} = union(helpVec, previous);
        end;
end
clear previous;
clear iBP;
for i = 1:size(x,2)
        iBP{i} = iHelp{i};
end;
clear iHelp;

% De-interpolating
for i = 1:size(iBP, 2) 
        iBP{i} = round(iBP{i}.*stepSize); % 20080130 is this correct? only one index?
end;


% Now calc the D's of the resulting sub-tracks using the breakpoints
% First dimension means trackIndex, second dimension means subtracks
% e.g. iD{3}(5) accesses D in track 3, subtrack 5
disp('Computing D and msd from sub-tracks');
for i = 1:size(trackIndeces, 2) % iterate through tracks
        j = find(trackIndeces(1:length(trackIndeces)-1,i)==1); % find relevant subtracks

        
        if isempty(iBP{i}) % no breakpoints found in x(j,i)...
                iD{i}(1) = maximumLikelihoodEstimation(x(j,i),deltaT); %...then average D over entire track, else...
                iMsqDpl{i}{1} = msd(trackMatrix(j,i*3-2:i*3));
                iTimeStampIndeces{i}{1} = timeStamp(j);
                iGraydata{i}(1) = median(grayvalueMatrix(:,i));
        else 
                        % Note that trackIndeces are not checked for in this branch, but x has been checked above 
                        iD{i}(1) = maximumLikelihoodEstimation(x(1:iBP{i}(1),i), deltaT); %...D for first sub-track
                        iMsqDpl{i}{1} = msd(trackMatrix(1:iBP{i}(1),i*3-2:i*3));
                        iTimeStampIndeces{i}{1} = timeStamp(1:iBP{i}(1));
                        iGraydata{i}(1) = median(grayvalueMatrix(1:iBP{i}(1),i));
                        for r = 2:length(iBP{i})
                                iD{i}(r) = maximumLikelihoodEstimation(x((iBP{i}(r-1)+1):iBP{i}(r),i), deltaT);         % sub-tracks 2:max-1
                                iMsqDpl{i}{r} = msd(trackMatrix((iBP{i}(r-1)+1):iBP{i}(r),i*3-2:i*3));
                                iTimeStampIndeces{i}{r} = timeStamp((iBP{i}(r-1)+1):iBP{i}(r));
                                iGraydata{i}(r) = median(grayvalueMatrix((iBP{i}(r-1)+1):iBP{i}(r),i));
                        end;
                        iD{i}(length(iD{i})+1) = maximumLikelihoodEstimation(x(iBP{i}(length(iBP{i})):length(x(:,i)),i), deltaT);
                        iMsqDpl{i}{length(iMsqDpl{i})+1} = msd(trackMatrix(iBP{i}(length(iBP{i})):length(x(:,i)),i*3-2:i*3));
                        iTimeStampIndeces{i}{length(iTimeStampIndeces{i})+1} = timeStamp(iBP{i}(length(iBP{i})):length(x(:,i)));
                        iGraydata{i}(length(iGraydata{i})+1) = median(grayvalueMatrix(iBP{i}(length(iBP{i})):length(x(:,i)), i));
        end;
end;
disp('done.');

% Estimate alpha coefficients of anomalous diffusion using fits to first 25% of msd plots
disp('Estimating alpha');
[alphaMatrix, resnormMatrix, fitMatrix, allAlphas, allDs, allResnorms, allDresiduals] = estimateAlpha(timeStamp, iMsqDpl, iD, iTimeStampIndeces);

% Provide plottable version of D vs time and Alpha vs time
disp('Computing vecD and vecA');
for i = 1:size(iTimeStampIndeces,2) 
        subTrackNumber = size(iTimeStampIndeces{i},2);
        for j = 1:subTrackNumber
                vecD(round(iTimeStampIndeces{i}{j}./deltaT)+1,i) = iD{i}(j);
                vecA(round(iTimeStampIndeces{i}{j}./deltaT)+1,i) = alphaMatrix{i}(j);
                vecG(round(iTimeStampIndeces{i}{j}./deltaT)+1,i) = iGraydata{i}(j);
                vecResnorm(round(iTimeStampIndeces{i}{j}./deltaT)+1,i) = resnormMatrix{i}(j);
        end;
end
disp('done.');

% Computing velocities
disp('Computing velocities');
veloMatrix = (x./deltaT).*60; 
disp('all done.');
%%%%% Auxilliary functions %%%%%%

function oBP = weedOutZeros(iBP)

for j = 1:size(iBP,2) % iterate through pieces
        for i = 1:size(iBP{j}, 2) % iterate through tracks
                iHelp{j}{i} = iBP{j}{i}(find(iBP{j}{i}~=0)); 
        end;
end
clear iBP;
oBP = iHelp;
clear iHelp;

function newCell = allocate2DCellArray(oldCell)

for j = 1:size(oldCell,2) % iterate through pieces
        for i = 1:size(oldCell{j}, 2) % iterate through tracks
                newCell{j}{i} = [];
        end;
end;
