function C = criticalRegion(N, alpha)
% C = criticalRegion(N, alpha)
% Reads tabulated critical region created using NOE's algorithm
% Actual values are interpolated from Table 1 in 
% Watkins and Yang J. Phys. Chem. B 2005, 109, 617-628
% There appears to be a confusion as to which column refers to which confidence
% Using Fig. 15 the oder has been reversed, the values have been calculated using
% eqn. 6 and 9
% Interpolation using interp1 and 'spline'
% Number of samples N = [1..1000]
% Interpolation leads to a deviation from the model for N < 10. 
% For N = 2 the deviation is about +10 %, N < 2 has a large error, but physically makes no sense
% alpha: confidence interval, can be '0.99', '0.95', '0.90', '0.69'
% alpha can be combined with 'c' for more conservative testing, e.g. '0.95c'
% ATTENTION: The file critical_region.mat containing the table must be in the search path

load critical_region.mat CR
load YI
CR = [CR, YI]; % YI contains confidence intervals [0.69..0.99] aquired by interp1 from [0.69, 0.9, 0.95, 0.99]
                % 0.nnc interpolations currently not available. 

clear YI;

switch alpha
        case '0.99'
                column = 2;
        case '0.99c'
                column = 3;
        case '0.95'
                column = 4;
        case '0.95c'
                column = 5;
        case '0.90'
                column = 6;
        case '0.90c'
                column = 7;
        case '0.69'
                column = 8;
        case '0.69c'
                column = 9;
        otherwise
                column = str2num(alpha).*100-58;
end;

C = CR(N,column);

