function [llr, breakpoints, breakpoints_b] = logLikelihoodRatio(x, deltaT, lastXmax, alpha)
% currentBreakpoint has to start at 1
% lastXmax must be =1 for first call. 2nd halves of tracks will be initialized with lastXmax+xmax to give offset to breakpoints. Without lastXmax the breakpoints would always be counted from 1

numberOfTimesteps = length(x);
Zn = 0;
xmax = [];
breakpoints = [];
breakpoints_b = [];
llr = 0;
if length(x)==0 disp('length(x) == 0'); return; end;
upperBound = numberOfTimesteps-2;
for k=2:upperBound % normally k goes to N-1, but there are some data sets with zeros at the end. 
        
        % Calculate MLEs
        D0 = maximumLikelihoodEstimation(x, deltaT);
        D1 = maximumLikelihoodEstimation(x(1:k), deltaT);
        D2 = maximumLikelihoodEstimation(x((k+1):(numberOfTimesteps)), deltaT);

        % Calculate llr
        llr(k) = numberOfTimesteps.*log(D0) - k.*log(D1) - (numberOfTimesteps-k).*log(D2);
        
        % Find maximum in llr and according abscissa
        if (llr(k) > Zn) 
                Zn = llr(k);
                xmax = k;
        end;    
end


% Now check with critical region if Zn is really significant
C = criticalRegion(numberOfTimesteps, alpha);
if (sqrt(Zn)>=C & numberOfTimesteps > 2 & ~isempty(xmax))
        breakpoints = xmax;
        [llr_, b_, b_b] = logLikelihoodRatio(x(1:xmax), deltaT, lastXmax, alpha);
        breakpoints = [breakpoints ; b_];
        breakpoints_b = [breakpoints_b ; b_b];
        
        [llr_, b_, b_b] = logLikelihoodRatio(x((xmax+1):numberOfTimesteps-2), deltaT, lastXmax+xmax, alpha);
        breakpoints = [breakpoints ; b_+lastXmax+xmax];
        breakpoints_b = [breakpoints_b ; b_b+lastXmax+xmax];
        
end;

% Now sort breakpoints
breakpoints = sort(breakpoints);
breakpoints_b = sort(breakpoints_b);
