function meanDisplacementVec = meanDisplacement(displacementMatrix, trackIndeces)
% meanDisplacementVec = meanDisplacement(displacementMatrix, trackIndeces)
% Calculates vector containing median of all displacemnts in
% displacementMatrix(time steps, number of tracks) 
% Only non-zero elements in trackIndeces are used for calculation

numberOfTracks = size(displacementMatrix, 2);
tSteps = size(displacementMatrix, 1);

meanArray = zeros(numberOfTracks, 1);
meanDisplacementVec = zeros(tSteps, 1);
elementNumber = 0; % Counts number of non-zero elements in trackIndeces per time-step (could be done with size(find(...==1)) as well)

for t = 1:tSteps
    for n = 1:numberOfTracks
        if (trackIndeces(t, n) == 1) % Use only non-zero elements in trackIndeces
            meanArray(n) = displacementMatrix(t, n); % store for calcing median
            elementNumber = elementNumber +1; 
        end;
    end;
    meanArray = sort(meanArray);
    offset = min(find(meanArray > 0)); % Zero elements in meanArray are not to be counted, since displacementMatrix contains only non-zeros for useful tracks
    meanDisplacementVec(t) =  mean(meanArray(offset:length(meanArray)));
    elementNumber = 0;
    %disp([num2str(meanArray'), ' : ', num2str(meanDisplacementVec(t))]);
    meanArray = zeros(numberOfTracks, 1);
end