function [trackMatrix, msdMatrix, estimates, fitMatrix, trafoMatrix, totalGrayValueMatrix, physicalVolumeMatrix, voxelNumberMatrix, M, N, weight, trackUsedInClassification, numberOfTracksPerPhase, alphaMatrix] = msdScript(varargin)
% [trackMatrix, msdMatrix, estimates, fitMatrix, trafoMatrix, totalGrayValueMatrix, physicalVolumeMatrix, voxelNumberMatrix, M, N, weight, trackUsedInClassification, numberOfTracksPerPhase, alphaMatrix] = msdScript(ypi, trackNumbers, trackIndeces, timeStamp, ypi2, trackPhases, startparameters, dimension, voxelsize)
% startparameters = [1 1] (fixed y axis intersect) or startparameters = [1 1 0] (variable y axis intersect)
warning off;

% fitoptions
fit2firstPercent = 0.25;
minPearson = 0.9;
% Gaussian Filter
sigma = 1;
kernelSize = 3;

if nargin > 8
    voxelsize = varargin{9};
    anisotropy = voxelsize(3)/sqrt(voxelsize(1)*voxelsize(2));
else anisotropy = 1;
end


if nargin > 7
    dimension = varargin{8};
else dimension = 2;    % ATTENTION: this is for 2D only (put 3 instead of 2 for 3D) or provide input param
end


ypi = varargin{1};
trackNumbers = varargin{2}
trackIndeces = varargin{3};
timeStamp = varargin{4};
if nargin > 6
    startparameters = varargin{7};
else startparameters = [1 1];
end;
% Init
trackMatrix = zeros(size(timeStamp, 1), size(trackNumbers,2).*3);
trafoMatrix = zeros(size(timeStamp, 1), 3);


 if nargin > 5 % trackPhases for Multiphase fitting provided
         trackPhases = varargin{6};
         msdMatrix = zeros(size(timeStamp, 1), size(trackNumbers,2), max(trackPhases));
         fitMatrix = zeros(size(timeStamp, 1), size(trackNumbers,2), max(trackPhases));
         sDirected = cell(1:max(trackPhases));
         sDiffusive = cell(1:max(trackPhases));
         sObstructed = cell(1:max(trackPhases));
         nDirected(1:max(trackPhases)) = 0;
         nDiffusive(1:max(trackPhases)) = 0;
         nObstructed(1:max(trackPhases)) = 0;
         n(1:max(trackPhases)) = 1;
         weight = ones(size(trackNumbers,2), max(trackPhases));
         trackUsedInClassification = zeros(size(trackNumbers,2), max(trackPhases));
         alphaMatrix = zeros(size(trackNumbers,2), max(trackPhases));
         M = zeros(3); %M must not have a singleton dimension, otherwise bar plot won't work 
         N = zeros(3);
         numberOfTracksPerPhase = zeros(1, max(trackPhases));
         totalGrayValueMatrix = zeros(length(timeStamp), length(trackNumbers));
         physicalVolumeMatrix = zeros(length(timeStamp), length(trackNumbers));
         voxelNumberMatrix = zeros(length(timeStamp), length(trackNumbers));

 else
         trackPhases = 1;
         msdMatrix = zeros(size(timeStamp, 1), size(trackNumbers,2));
         fitMatrix = zeros(size(timeStamp, 1), size(trackNumbers,2));
         disp('No trackPhases provided.')
         nDirected(1:max(trackPhases)) = 0;
         nDiffusive(1:max(trackPhases)) = 0;
         nObstructed(1:max(trackPhases)) = 0;
         n(1:max(trackPhases)) = 1;
         sDirected = cell(1:max(trackPhases));
         sDiffusive = cell(1:max(trackPhases));
         sObstructed = cell(1:max(trackPhases));
         weight = ones(size(trackNumbers,2), max(trackPhases));
         trackUsedInClassification = zeros(size(trackNumbers,2), max(trackPhases));
         alphaMatrix = zeros(size(trackNumbers,2), max(trackPhases));
         M = zeros(3); %M must not have a singleton dimension, otherwise bar plot won't work
         N = zeros(3);
         numberOfTracksPerPhase = zeros(1, max(trackPhases));
         totalGrayValueMatrix = zeros(length(timeStamp), length(trackNumbers));
         physicalVolumeMatrix = zeros(length(timeStamp), length(trackNumbers));
         voxelNumberMatrix = zeros(length(timeStamp), length(trackNumbers));
end;



if (nargin > 4) & (~isequal(varargin{5},[])) & (~strcmp(varargin{5},'COM'))% translation matrix provided
    
    ypi2 = varargin{5};
    %!!!Attention!!! Make sure data starts at row 1 (or specify otherwise)
    data = dlmread(ypi2, '\t', 2, 0);
    trafoMatrix(:,1) = data(:,2);
    trafoMatrix(:,2) = data(:,3);
    trafoMatrix(:,3) = data(:,4);
    

    for i = 1:size(trackNumbers,2)
        disp([ypi, num2str(trackNumbers(i)), '.txt']);
        data = dlmread([ypi, num2str(trackNumbers(i)), '.txt'], '\t', 2, 0);
        
        for j = 1:size(timeStamp,1)
          if trackIndeces(j,i) == 1
             trackMatrix(j, i*3-2) = data(j, 2);
             trackMatrix(j, i*3-1) = data(j, 3);
             trackMatrix(j, i*3) = data(j,4);
            
             % Translation
             trackMatrix(j, i*3-2) = trackMatrix(j, i*3-2) - trafoMatrix(j,1);
             trackMatrix(j, i*3-1) = trackMatrix(j, i*3-1) - trafoMatrix(j,2);
             trackMatrix(j, i*3) = trackMatrix(j, i*3) - trafoMatrix(j,3);
            
          end;
        end;% j
        
        % Linear interopolation of gaps (zeros) in tracks
        trackMatrix(:, i) = interpolategaps(trackMatrix(:, i));
  
        % Include anisotropy, if provided. By default anisotropy is 1. 
        if(~mod(i,3)) trackMatrix(:,i) = trackMatrix(:,i).*anisotropy; end;
        
     % Calc MSDs  
     for r = 1:max(trackPhases)  m{r} = find(trackIndeces(:,i)==1 & trackPhases==r); index = m{r} - min(m{r})+1; msdMatrix(index,i,r)=msd(trackMatrix(m{r},i*3-2:i*3)); msdMatrix(index,i,r) = msdMatrix(index,i,r)-msdMatrix(1,i,r); clear index; 
     
     
    %%%%%%%%%%%% Fitting %%%%%%%%%%%%
    %fitToTimepoint = round((size(msdMatrix,1)-size(find(msdMatrix(:,i,r)==0),1)).*fit2firstPercent);     
    fitToTimepoint = round(find(msdMatrix(:,i,r)==max(msdMatrix(:,i,r))).*fit2firstPercent);
    %round(sum(trackIndeces(:,i)).*0.4);
    if size(startparameters,2) == 3
        estimates(i,[1:2,size(startparameters,2)+1], r) = fitcurve(timeStamp(1:fitToTimepoint), msdMatrix(1:fitToTimepoint, i, r), startparameters, dimension);
        %disp('y axis intercept FITTED')
    else
        estimates(i,[1:2], r) = fitcurve(timeStamp(1:fitToTimepoint), msdMatrix(1:fitToTimepoint, i, r), startparameters, dimension);
        estimates(i, 4, r) = 0;
        %disp('y axis intercept FIXED')
    end
    % ATTENTION: this is for 2D only (put 3 instead of 2 for 3D)
    fitvalues = diffusion([estimates(i,1, r), estimates(i,2,r), estimates(i,4,r), dimension], timeStamp(1:fitToTimepoint));
    fitMatrix(1:size(fitvalues,1),i,r) = fitvalues;
    R(r) = pearsonsr(msdMatrix(1:fitToTimepoint, i, r),fitMatrix(1:fitToTimepoint, i, r)).^2;
    estimates(i,3,r) = R(r);
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     
   %Calculate weights for track length in respective phase
     usableTrackLength = sum(trackIndeces(find(trackPhases==r),i));
     totalTrackLengthInPhase = sum(trackPhases(find(trackPhases==r)))./r;
     weight(i, r) = usableTrackLength./totalTrackLengthInPhase;
    
    
    % For evaluation s. below
    alpha = estimates(i,2,r);
        
            if alpha > 1.25 & alpha < 2 & R(r) > minPearson & R(r) < 1
                 nDirected(r) = nDirected(r) + weight(i,r);
                 trackUsedInClassification(i, r) = 1;
                alphaMatrix(i, r) = alpha; 
                 sDirected{r} = [sDirected{r}, num2str(i), ' , ']; 
            elseif alpha > 0.75 & alpha <= 1.25 & R(r) > minPearson & R(r) < 1
                 nDiffusive(r) = nDiffusive(r) + weight(i,r) ;
                 trackUsedInClassification(i, r) = 1;
                alphaMatrix(i, r) = alpha; 
                 sDiffusive{r} = [sDiffusive{r}, num2str(i), ' , ']; 
            elseif alpha > 0.4 & alpha <= 0.75 & R(r) > minPearson & R(r) < 1
                 trackUsedInClassification(i, r) = 1;
                alphaMatrix(i, r) = alpha; 
                 nObstructed(r) = nObstructed(r) + weight(i,r);
                 sObstructed{r} = [sObstructed{r}, num2str(i), ' , ']; 
            end
    
     
     nDirected(r) = nDirected(r);%./n(r);
     nDiffusive(r) = nDiffusive(r);%./n(r);
     nObstructed(r) = nObstructed(r);%./n(r);
     M(1, r) = nDirected(r);
     M(2, r) = nDiffusive(r);
     M(3, r) = nObstructed(r);
     N(:,r)=M(:,r);
     M(:,r) = M(:,r)./sum(M(:,r));
     end % r
     
    end;  % i
    numberOfTracksPerPhase = sum(trackUsedInClassification);
    
    %%%%%%%%%%%% EVALUATION %%%%%%%%%%%%%
    
     
  
    h = figure('Position', get(0,'ScreenSize'));
    bar(M', 'stack'); 
     title('Classification of movement type (Translation)', 'FontSize', 16)
     legend( 'Directed','Diffusive', 'Obstructed', 'FontSize', 16)
     %legend({'Directed', sDirected{r}},{'Diffusive', sDiffusive{r}}, {'Obstructed', sObstructed{r}})
     xlabel('Phase', 'FontSize', 16);
    saveas(h, ['Classification_withTranslation.fig'], 'fig'); 
    %saveas(h, ['Classification_withTranslation.png'], 'png'); 
      
    % Plot displacement
    x = displacement(trackMatrix);
    for i = 1:size(x,2) v(:,i) = gaussianFilter_old(x(:,i)); end;
    meanDisplacementVec = meanDisplacement(v, trackIndeces);
    figure;
    plot(1:size(v,1), v, 1:size(v,1), meanDisplacementVec, 'ko'); xlabel('step number', 'FontSize', 16); ylabel('displacement in \mum per step', 'FontSize', 16); ylim([0 1]);
    saveas(h, ['displacement.fig'], 'fig');
    
    
    % Plot MSDs
    plotMatrix(timeStamp, msdMatrix, trackNumbers, 'MSD vs. timeinterval (Translation)', 'MSD [\mum^2]', '\Deltat [s]', 'MSD_withTranslation', fitMatrix, estimates, fit2firstPercent);
    % plotMatrix(timeStamp, fitMatrix, trackNumbers, 'FIT vs. timeinterval', 'MSD [s]', 'time [s]', 'FIT')
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END TRANSLATION
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
    
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%% NO TRANSLATION MATRIX, BUT TRANSFORMATION TO CENTER OF MASS (COM) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%55   
 
elseif (nargin > 4) & (isequal(varargin{5},'COM'))% no translation matrix provided
    
    
    
    

    for i = 1:size(trackNumbers,2)
        disp([ypi, num2str(trackNumbers(i)), '.txt']);
        data = dlmread([ypi, num2str(trackNumbers(i)), '.txt'], '\t', 2, 0);
        
        for j = 1:size(timeStamp,1)
          if trackIndeces(j,i) == 1
             % Fill track matrix
             trackMatrix(j, i*3-2) = data(j, 2);
             trackMatrix(j, i*3-1) = data(j, 3);
             trackMatrix(j, i*3) = data(j,4);
             totalGrayValueMatrix(j, i) = data(j, 5);
             physicalVolumeMatrix(j, i) = data(j, 6);
             voxelNumberMatrix(j, i) = data(j, 7);
          end;
        end;% j
         % Include anisotropy, if provided. By default anisotropy is 1. 
            if(~mod(i,3)) trackMatrix(:,i) = trackMatrix(:,i).*anisotropy; end;
     end %i
        % Linear interopolation of gaps (zeros) in tracks
          trackMatrix = interpolategaps(trackMatrix);  
        
     %%%%%% COORD TRAFO TO COM %%%%%%%%
     %% Fill trafo Matrix
     trafoMatrix(:,1) = mean(trackMatrix(:,1:size(trackNumbers,2)*3-2),2);
     trafoMatrix(:,2) = mean(trackMatrix(:,1:size(trackNumbers,2)*3-1),2);
     trafoMatrix(:,3) = mean(trackMatrix(:,1:size(trackNumbers,2)*3),2);
     
   
     
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     
     
     for i = 1:size(trackNumbers,2) %% resume iterating through tracks for msd and eval   
           %% Do trafo
            %trackMatrix(:,1:size(trackNumbers,2)*3-2) = trackMatrix(:,1:size(trackNumbers,2)*3-2)-trafoMatrix(:,1);
           for j = 1:size(timeStamp,1)
                if trackIndeces(j,i) == 1
                    trackMatrix(j, i*3-2) = trackMatrix(j, i*3-2) - trafoMatrix(j,1);
                    trackMatrix(j, i*3-1) = trackMatrix(j, i*3-1) - trafoMatrix(j,2);
                    trackMatrix(j, i*3) = trackMatrix(j, i*3) - trafoMatrix(j,3);
                end;
            end;% j
     
     % Calc MSDs  
     for r = 1:max(trackPhases)  m{r} = find(trackIndeces(:,i)==1 & trackPhases==r); index = m{r} - min(m{r})+1; msdMatrix(index,i,r)=msd(trackMatrix(m{r},i*3-2:i*3)); msdMatrix(index,i,r) = msdMatrix(index,i,r)-msdMatrix(1,i,r); clear index; 
     
      
    
    %%%%%%%%%%%% Fitting %%%%%%%%%%%%
    %fitToTimepoint = round((size(msdMatrix,1)-size(find(msdMatrix(:,i,r)==0),1)).*fit2firstPercent);
    fitToTimepoint = round(find(msdMatrix(:,i,r)==max(msdMatrix(:,i,r))).*fit2firstPercent);
    %round(sum(trackIndeces(:,i)).*0.4);
    if size(startparameters,2) == 3
        estimates(i,[1:2,size(startparameters,2)+1], r) = fitcurve(timeStamp(1:fitToTimepoint), msdMatrix(1:fitToTimepoint, i, r), startparameters, dimension);
        %disp('y axis intercept FITTED')
    else
        estimates(i,[1:2], r) = fitcurve(timeStamp(1:fitToTimepoint), msdMatrix(1:fitToTimepoint, i, r), startparameters, dimension);
        estimates(i, 4, r) = 0;
        %disp('y axis intercept FIXED')
    end
    % ATTENTION: this is for 2D only (put 3 instead of 2 for 3D)
    fitvalues = diffusion([estimates(i,1, r), estimates(i,2,r), estimates(i,4,r), dimension], timeStamp(1:fitToTimepoint));
    fitMatrix(1:size(fitvalues,1),i,r) = fitvalues;
    R(r) = pearsonsr(msdMatrix(1:fitToTimepoint, i, r),fitMatrix(1:fitToTimepoint, i, r)).^2;
    estimates(i,3,r) = R(r);
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    %Calculate weights for track length in respective phase
     usableTrackLength = sum(trackIndeces(find(trackPhases==r),i));
     totalTrackLengthInPhase = sum(trackPhases(find(trackPhases==r)))./r;
     weight(i, r) = usableTrackLength./totalTrackLengthInPhase;
    
    
    % For evaluation s. below
    alpha = estimates(i,2,r);
        
            if alpha > 1.25 & alpha < 2 & R(r) > minPearson & R(r) < 1
                 nDirected(r) = nDirected(r) + weight(i,r); % used to be nDirected = nDirected + 1, weight = 1 as long as all time points are used
                 trackUsedInClassification(i, r) = 1;
                alphaMatrix(i, r) = alpha; 
                 sDirected{r} = [sDirected{r}, num2str(i), ' , ']; 
            elseif alpha > 0.75 & alpha <= 1.25 & R(r) > minPearson & R(r) < 1
                 nDiffusive(r) = nDiffusive(r) + weight(i,r) ;
                 trackUsedInClassification(i, r) = 1;
                alphaMatrix(i, r) = alpha; 
                 sDiffusive{r} = [sDiffusive{r}, num2str(i), ' , ']; 
            elseif alpha > 0.4 & alpha <= 0.75 & R(r) > minPearson & R(r) < 1
                 trackUsedInClassification(i, r) = 1;
                alphaMatrix(i, r) = alpha; 
                 nObstructed(r) = nObstructed(r) + weight(i,r);
                 sObstructed{r} = [sObstructed{r}, num2str(i), ' , ']; 
            end
    
     
     nDirected(r) = nDirected(r);%./n(r);
     nDiffusive(r) = nDiffusive(r);%./n(r);
     nObstructed(r) = nObstructed(r);%./n(r);
     M(1, r) = nDirected(r);
     M(2, r) = nDiffusive(r);
     M(3, r) = nObstructed(r);
     N(:,r)=M(:,r);
     M(:,r) = M(:,r)./sum(M(:,r));
     end % r
     
    end;  % i
    numberOfTracksPerPhase = sum(trackUsedInClassification);
   
    %%%%%%%%%%%% EVALUATION %%%%%%%%%%%%%

    h = figure('Position', get(0,'ScreenSize'));
    bar(M', 'stack'); 
     title('Classification of movement type (COM)', 'FontSize', 16)
     legend( 'Directed','Diffusive', 'Obstructed', 'FontSize', 16)
     %legend({'Directed', sDirected{r}},{'Diffusive', sDiffusive{r}}, {'Obstructed', sObstructed{r}})
     xlabel('Phase', 'FontSize', 16);
    saveas(h, ['Classification_COM.fig'], 'fig'); 
    %saveas(h, ['Classification_COM.png'], 'png'); 
    % Plot MSDs
    plotMatrix(timeStamp, msdMatrix, trackNumbers, 'MSD vs. timeinterval (COM)', 'MSD [\mum^2]', '\Deltat [s]', 'MSD_COM', fitMatrix, estimates, fit2firstPercent);
    
    % Plot displacement
    x = displacement(trackMatrix);
    for i = 1:size(x,2) v(:,i) = gaussianFilter_old(x(:,i)); end;
    meanDisplacementVec = meanDisplacement(v, trackIndeces);
    figure;
    plot(1:size(v,1), v, 1:size(v,1), meanDisplacementVec, 'ko'); xlabel('step number', 'FontSize', 16); ylabel('displacement in \mum per step', 'FontSize', 16); ylim([0 1]);
    saveas(h, ['displacement.fig'], 'fig');
    % plotMatrix(timeStamp, fitMatrix, trackNumbers, 'FIT vs. timeinterval', 'MSD [s]', 'time [s]', 'FIT')
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  END OF TRAFO COM
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
    
    
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% NO TRANSLATION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
else % no translation 
disp('No translation matrix provided.')
   
 for i = 1:size(trackNumbers,2)
        disp([ypi, num2str(trackNumbers(i)), '.txt']);
        data = dlmread([ypi, num2str(trackNumbers(i)), '.txt'], '\t', 2, 0);
        
        for j = 1:size(timeStamp,1)
          if trackIndeces(j,i) == 1
             trackMatrix(j, i*3-2) = data(j, 2);
             trackMatrix(j, i*3-1) = data(j, 3);
             trackMatrix(j, i*3) = data(j,4);
                         
          end;
        end;% j
         % Include anisotropy, if provided. By default anisotropy is 1. 
            if(~mod(i,3)) trackMatrix(:,i) = trackMatrix(:,i).*anisotropy; end;
         % Linear interopolation of gaps (zeros) in tracks
                trackMatrix(:, i) = interpolategaps(trackMatrix(:, i));
        
     % Calc MSDs  
     for r = 1:max(trackPhases)  m{r} = find(trackIndeces(:,i)==1 & trackPhases==r); index = m{r} - min(m{r})+1; msdMatrix(index,i,r)=msd(trackMatrix(m{r},i*3-2:i*3));  msdMatrix(index,i,r) = msdMatrix(index,i,r)-msdMatrix(1,i,r); clear index; 
     
      
    
     
     
    %%%%%%%%%%%% Fitting %%%%%%%%%%%%
    %fitToTimepoint = round((size(msdMatrix,1)-size(find(msdMatrix(:,i,r)==0),1)).*fit2firstPercent);    
    fitToTimepoint = round(find(msdMatrix(:,i,r)==max(msdMatrix(:,i,r))).*fit2firstPercent);
    %round(sum(trackIndeces(:,i)).*0.4);
    if size(startparameters,2) == 3
        estimates(i,[1:2,size(startparameters,2)+1], r) = fitcurve(timeStamp(1:fitToTimepoint), msdMatrix(1:fitToTimepoint, i, r), startparameters, dimension);
        %disp('y axis intercept FITTED')
    else
        estimates(i,[1:2], r) = fitcurve(timeStamp(1:fitToTimepoint), msdMatrix(1:fitToTimepoint, i, r), startparameters, dimension);
        estimates(i, 4, r) = 0;
        %disp('y axis intercept FIXED')
    end
    % ATTENTION: this is for 2D only (put 3 instead of 2 for 3D)
    fitvalues = diffusion([estimates(i,1, r), estimates(i,2,r), estimates(i,4,r), dimension], timeStamp(1:fitToTimepoint));
    fitMatrix(1:size(fitvalues,1),i,r) = fitvalues;
    R(r) = pearsonsr(msdMatrix(1:fitToTimepoint, i, r),fitMatrix(1:fitToTimepoint, i, r)).^2;
    estimates(i,3,r) = R(r);
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     
   %Calculate weights for track length in respective phase
     usableTrackLength = sum(trackIndeces(find(trackPhases==r),i));
     totalTrackLengthInPhase = sum(trackPhases(find(trackPhases==r)))./r;
     weight(i, r) = usableTrackLength./totalTrackLengthInPhase;
    
    
    % For evaluation s. below
    alpha = estimates(i,2,r);
        
            if alpha > 1.25 & alpha < 2 & R(r) > minPearson & R(r) < 1
                 nDirected(r) = nDirected(r) + weight(i,r);
                 trackUsedInClassification(i, r) = 1;
                alphaMatrix(i, r) = alpha; 
                 sDirected{r} = [sDirected{r}, num2str(i), ' , ']; 
            elseif alpha > 0.75 & alpha <= 1.25 & R(r) > minPearson & R(r) < 1
                 nDiffusive(r) = nDiffusive(r) + weight(i,r) ;
                 trackUsedInClassification(i, r) = 1;
                alphaMatrix(i, r) = alpha; 
                 sDiffusive{r} = [sDiffusive{r}, num2str(i), ' , ']; 
            elseif alpha > 0.4 & alpha <= 0.75 & R(r) > minPearson & R(r) < 1
                 trackUsedInClassification(i, r) = 1;
                alphaMatrix(i, r) = alpha; 
                 nObstructed(r) = nObstructed(r) + weight(i,r);
                 sObstructed{r} = [sObstructed{r}, num2str(i), ' , ']; 
            end
    
     nDirected(r) = nDirected(r);%./n(r);
     nDiffusive(r) = nDiffusive(r);%./n(r);
     nObstructed(r) = nObstructed(r);%./n(r);
     M(1, r) = nDirected(r);
     M(2, r) = nDiffusive(r);
     M(3, r) = nObstructed(r);
     N(:,r)=M(:,r);
     M(:,r) = M(:,r)./sum(M(:,r));
     end % r
     
    end;  % i
    
    numberOfTracksPerPhase = sum(trackUsedInClassification);
    h = figure('Position', get(0,'ScreenSize'));
    bar(M', 'stack'); 
     title('Classification of movement type', 'FontSize', 16)
     legend( 'Directed','Diffusive', 'Obstructed', 'FontSize', 16)
     %legend({'Directed', sDirected{r}},{'Diffusive', sDiffusive{r}}, {'Obstructed', sObstructed{r}})
     xlabel('Phase', 'FontSize', 16);
    saveas(h, ['Classification_noTranslation.fig'], 'fig'); 
    %saveas(h, ['Classification_noTranslation.png'], 'png'); 
    
    % Plot displacement
    x = displacement(trackMatrix);
    for i = 1:size(x,2) v(:,i) = gaussianFilter_old(x(:,i)); end;
    meanDisplacementVec = meanDisplacement(v, trackIndeces);
    figure;
    plot(1:size(v,1), v, 1:size(v,1), meanDisplacementVec, 'ko'); xlabel('step number', 'FontSize', 16); ylabel('displacement in \mum per step', 'FontSize', 16); %ylim([0 1]);
    saveas(h, ['displacement.fig'], 'fig');
    
    % Plot MSDs
    plotMatrix(timeStamp, msdMatrix, trackNumbers, 'MSD vs. timeinterval (no Translation)', 'MSD [\mum^2]', '\Deltat [s]', 'MSD_noTranslation', fitMatrix, estimates, fit2firstPercent);
    % plotMatrix(timeStamp, fitMatrix, trackNumbers, 'FIT vs. timeinterval', 'MSD [s]', 'time [s]', 'FIT')
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    
end % if (Translation?)




warning on;
